Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildCommentary ¶
BuildCommentary appends a commentary block to an existing showboat document.
func BuildImage ¶
BuildImage appends an image code block, runs the script, captures the image.
func Extract ¶
Extract parses a showboat document and returns the sequence of CLI commands that would recreate it. OutputBlock and ImageOutputBlock are skipped since they are generated by running code blocks. If outputFile is non-empty it is used as the filename in the emitted commands; otherwise the input file path is used.
Types ¶
type Diff ¶
Diff represents a mismatch between expected and actual output of a code block.
Click to show internal directories.
Click to hide internal directories.