exec

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(lang, code, workdir string) (string, int, error)

Run executes code using the given language interpreter and returns the combined stdout+stderr output and the process exit code. Non-zero exit codes are not treated as errors — the output is still captured and returned alongside the exit code. If workdir is empty, the current directory is used.

func RunImage

func RunImage(script, destDir, workdir string) (string, error)

RunImage runs a bash script that is expected to produce an image file. The last line of stdout is treated as the path to the image. The image is copied to destDir with a <uuid>-<date>.<ext> filename. Returns the new filename (not the full path).

Types

This section is empty.

Jump to