Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Run ¶
Run executes code using the given language interpreter and returns the combined stdout+stderr output and the process exit code. Non-zero exit codes are not treated as errors — the output is still captured and returned alongside the exit code. If workdir is empty, the current directory is used.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.