Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CommentaryBlock ¶
type CommentaryBlock struct {
Text string
}
CommentaryBlock is free-form markdown prose.
func (CommentaryBlock) Type ¶
func (b CommentaryBlock) Type() string
type ImageOutputBlock ¶
ImageOutputBlock is a captured image reference from an image code block.
func (ImageOutputBlock) Type ¶
func (b ImageOutputBlock) Type() string
type OutputBlock ¶
type OutputBlock struct {
Content string
}
OutputBlock is captured text output from a code block.
func (OutputBlock) Type ¶
func (b OutputBlock) Type() string
type TitleBlock ¶
TitleBlock is the document header: an H1 title and a timestamp.
func (TitleBlock) Type ¶
func (b TitleBlock) Type() string
Click to show internal directories.
Click to hide internal directories.